==============================================
:mod:`numina.dal` --- Calibration fetching
==============================================

.. automodule:: numina.dal
   :members:


.. automodule:: numina.dal.daliface
   :members:

.. automodule:: numina.dal.absdal
   :members:

.. automodule:: numina.dal.dictdal
   :members:

.. automodule:: numina.dal.diskfiledal
   :members:

.. automodule:: numina.dal.mockdal
   :members:

.. automodule:: numina.dal.stored
   :members:

.. automodule:: numina.dal.backend
   :members:


.. automodule:: numina.dal.utils
   :members: